@@ -1,10 +1,10 @@
-# 0 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
-# 0 "<built-in>"
-# 0 "<command-line>"
+# 1 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1 "<built-in>"
+# 1 "<command-line>"
 # 1 "/usr/include/stdc-predef.h" 1 3 4
-# 0 "<command-line>" 2
-# 1 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
-# 48 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1 "<command-line>" 2
+# 1 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 48 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef void (*flux_free_f)(void *arg);
 
 
@@ -13,7 +13,7 @@ typedef void (*flux_free_f)(void *arg);
 typedef struct {
     char text[160];
 } flux_error_t;
-# 104 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 104 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_msg flux_msg_t;
 
 enum {
@@ -60,7 +60,7 @@ void flux_match_free (struct flux_match m);
 int flux_match_asprintf (struct flux_match *m,
                          const char *topic_glob_fmt,
                          ...);
-# 178 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 178 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_msg_t *flux_msg_create (int type);
 void flux_msg_destroy (flux_msg_t *msg);
 
@@ -169,7 +169,7 @@ int flux_msg_vpack (flux_msg_t *msg, const char *fmt, va_list ap);
 
 int flux_msg_unpack (const flux_msg_t *msg, const char *fmt, ...);
 int flux_msg_vunpack (const flux_msg_t *msg, const char *fmt, va_list ap);
-# 294 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 294 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_msg_last_error (const flux_msg_t *msg);
 
 
@@ -191,6 +191,7 @@ enum {
     FLUX_ROLE_NONE = 0,
     FLUX_ROLE_OWNER = 1,
     FLUX_ROLE_USER = 2,
+    FLUX_ROLE_LOCAL = 4,
     FLUX_ROLE_ALL = 0xFFFFFFFF,
 };
 int flux_msg_set_rolemask (flux_msg_t *msg, uint32_t rolemask);
@@ -220,6 +221,11 @@ int flux_msg_authorize (const flux_msg_t *msg, uint32_t userid);
 
 
 
+
+bool flux_msg_is_local (const flux_msg_t *msg);
+
+
+
 int flux_msg_set_errnum (flux_msg_t *msg, int errnum);
 int flux_msg_get_errnum (const flux_msg_t *msg, int *errnum);
 
@@ -255,7 +261,7 @@ void flux_msg_fprint_ts (FILE *f, const flux_msg_t *msg, double timestamp);
 
 
 const char *flux_msg_typestr (int type);
-# 389 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 395 "/__w/flux-python/flux-python/src/_core_clean.h"
 void flux_msg_route_enable (flux_msg_t *msg);
 
 
@@ -314,7 +320,7 @@ char *flux_msg_route_string (const flux_msg_t *msg);
 
 bool flux_msg_route_match_first (const flux_msg_t *msg1,
                                  const flux_msg_t *msg2);
-# 463 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 469 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_handle_struct flux_t;
 
 typedef struct {
@@ -355,7 +361,7 @@ enum {
     FLUX_POLLOUT = 2,
     FLUX_POLLERR = 4,
 };
-# 516 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 522 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_t *flux_open (const char *uri, int flags);
 
 
@@ -391,7 +397,7 @@ int flux_opt_get (flux_t *h, const char *option, void *val, size_t len);
 
 
 void flux_comms_error_set (flux_t *h, flux_comms_error_f fun, void *arg);
-# 560 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 566 "/__w/flux-python/flux-python/src/_core_clean.h"
 void *flux_aux_get (flux_t *h, const char *name);
 int flux_aux_set (flux_t *h, const char *name, void *aux, flux_free_f destroy);
 
@@ -413,7 +419,7 @@ uint32_t flux_matchtag_avail (flux_t *h);
 
 
 int flux_send (flux_t *h, const flux_msg_t *msg, int flags);
-# 589 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 595 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_msg_t *flux_recv (flux_t *h, struct flux_match match, int flags);
 
 
@@ -428,14 +434,14 @@ int flux_requeue (flux_t *h, const flux_msg_t *msg, int flags);
 
 
 int flux_pollevents (flux_t *h);
-# 613 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 619 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_pollfd (flux_t *h);
 
 
 
 void flux_get_msgcounters (flux_t *h, flux_msgcounters_t *mcs);
 void flux_clr_msgcounters (flux_t *h);
-# 661 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 667 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_buffer flux_buffer_t;
 
 
@@ -452,7 +458,7 @@ int flux_buffer_bytes (flux_buffer_t *fb);
 
 
 int flux_buffer_space (flux_buffer_t *fb);
-# 687 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 693 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_buffer_readonly (flux_buffer_t *fb);
 bool flux_buffer_is_readonly (flux_buffer_t *fb);
 
@@ -460,9 +466,9 @@ bool flux_buffer_is_readonly (flux_buffer_t *fb);
 
 
 int flux_buffer_drop (flux_buffer_t *fb, int len);
-# 702 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 708 "/__w/flux-python/flux-python/src/_core_clean.h"
 const void *flux_buffer_peek (flux_buffer_t *fb, int len, int *lenp);
-# 712 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 718 "/__w/flux-python/flux-python/src/_core_clean.h"
 const void *flux_buffer_read (flux_buffer_t *fb, int len, int *lenp);
 
 
@@ -523,7 +529,7 @@ int flux_buffer_read_to_fd (flux_buffer_t *fb, int fd, int len);
 
 
 int flux_buffer_write_from_fd (flux_buffer_t *fb, int fd, int len);
-# 788 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 794 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_reactor flux_reactor_t;
 
 
@@ -615,12 +621,18 @@ const char *flux_buffer_read_watcher_get_data (flux_watcher_t *w,
                                                int *lenp);
 
 
+
+
+void flux_buffer_read_watcher_incref (flux_watcher_t *w);
+void flux_buffer_read_watcher_decref (flux_watcher_t *w);
+
+
 flux_watcher_t *flux_buffer_write_watcher_create (flux_reactor_t *r, int fd,
                                                   int size, flux_watcher_f cb,
                                                   int flags, void *arg);
 
 flux_buffer_t *flux_buffer_write_watcher_get_buffer (flux_watcher_t *w);
-# 894 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 906 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_buffer_write_watcher_close (flux_watcher_t *w);
 
 
@@ -698,7 +710,7 @@ struct flux_watcher_ops {
     void (*stop) (flux_watcher_t *w);
     void (*destroy) (flux_watcher_t *w);
 };
-# 979 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 991 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_watcher_t * flux_watcher_create (flux_reactor_t *r, size_t data_size,
                                       struct flux_watcher_ops *ops,
                                       flux_watcher_f fn, void *arg);
@@ -710,7 +722,7 @@ void * flux_watcher_get_data (flux_watcher_t *w);
 
 
 struct flux_watcher_ops * flux_watcher_get_ops (flux_watcher_t *w);
-# 1018 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1030 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_msg_handler flux_msg_handler_t;
 
 typedef void (*flux_msg_handler_f)(flux_t *h, flux_msg_handler_t *mh,
@@ -757,7 +769,7 @@ void flux_msg_handler_delvec (flux_msg_handler_t *msg_handlers[]);
 
 
 int flux_dispatch_requeue (flux_t *h);
-# 1095 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1107 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef flux_t *(connector_init_f)(const char *uri,
                                    int flags,
                                    flux_error_t *errp);
@@ -778,7 +790,7 @@ struct flux_handle_ops {
 
 flux_t *flux_handle_create (void *impl, const struct flux_handle_ops *ops, int flags);
 void flux_handle_destroy (flux_t *hp);
-# 1146 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1158 "/__w/flux-python/flux-python/src/_core_clean.h"
 struct flux_msglist *flux_msglist_create (void);
 void flux_msglist_destroy (struct flux_msglist *l);
 
@@ -792,10 +804,10 @@ const flux_msg_t *flux_msglist_next (struct flux_msglist *l);
 const flux_msg_t *flux_msglist_last (struct flux_msglist *l);
 
 int flux_msglist_count (struct flux_msglist *l);
-# 1167 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1179 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_msglist_pollevents (struct flux_msglist *l);
 int flux_msglist_pollfd (struct flux_msglist *l);
-# 1203 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1215 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_request_decode (const flux_msg_t *msg, const char **topic,
                          const char **s);
 
@@ -826,10 +838,10 @@ flux_msg_t *flux_request_encode (const char *topic, const char *s);
 
 flux_msg_t *flux_request_encode_raw (const char *topic,
                                      const void *data, int len);
-# 1269 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1281 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_response_decode (const flux_msg_t *msg, const char **topic,
                           const char **s);
-# 1280 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1292 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_response_decode_raw (const flux_msg_t *msg, const char **topic,
                               const void **data, int *len);
 
@@ -884,11 +896,11 @@ int flux_respond_raw (flux_t *h, const flux_msg_t *request,
 
 int flux_respond_error (flux_t *h, const flux_msg_t *request,
                         int errnum, const char *errstr);
-# 1362 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1374 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_msg_t *flux_control_encode (int type, int status);
 
 int flux_control_decode (const flux_msg_t *msg, int *type, int *status);
-# 1423 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1435 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef void (*flux_log_f)(const char *buf, int len, void *arg);
 
 
@@ -940,7 +952,7 @@ void flux_llog (void *arg,
                 int level,
                 const char *fmt,
                 va_list ap);
-# 1493 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1505 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_future flux_future_t;
 
 typedef void (*flux_continuation_f)(flux_future_t *f, void *arg);
@@ -1006,7 +1018,7 @@ const char * flux_future_first_child (flux_future_t *cf);
 const char * flux_future_next_child (flux_future_t *cf);
 
 flux_future_t *flux_future_get_child (flux_future_t *cf, const char *name);
-# 1571 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1583 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_future_and_then (flux_future_t *f,
                                      flux_continuation_f cb, void *arg);
 
@@ -1034,7 +1046,7 @@ void flux_future_continue_error (flux_future_t *prev, int errnum,
 int flux_future_fulfill_next (flux_future_t *prev,
                               void *result,
                               flux_free_f free_fn);
-# 1613 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1625 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum {
     FLUX_RPC_NORESPONSE = 1,
     FLUX_RPC_STREAMING = 2,
@@ -1072,9 +1084,9 @@ uint32_t flux_rpc_get_matchtag (flux_future_t *f);
 
 
 uint32_t flux_rpc_get_nodeid (flux_future_t *f);
-# 1682 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1694 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_panic (flux_t *h, uint32_t nodeid, int flags, const char *reason);
-# 1711 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1723 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum event_flags {
     FLUX_EVENT_PRIVATE = 1,
 };
@@ -1155,7 +1167,7 @@ flux_future_t *flux_event_publish_raw (flux_t *h,
 
 
 int flux_event_publish_get_seq (flux_future_t *f, int *seq);
-# 1822 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1834 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum {
     FLUX_MODSTATE_INIT = 0,
     FLUX_MODSTATE_RUNNING = 1,
@@ -1181,7 +1193,7 @@ bool flux_module_debug_test (flux_t *h, int flag, bool clear);
 
 
 int flux_module_set_running (flux_t *h);
-# 1895 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1907 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_attr_get (flux_t *h, const char *name);
 
 
@@ -1216,7 +1228,7 @@ const char *flux_get_hostbyrank (flux_t *h, uint32_t rank);
 
 
 int flux_get_rankbyhost (flux_t *h, const char *host);
-# 1943 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1955 "/__w/flux-python/flux-python/src/_core_clean.h"
 char *flux_hostmap_lookup (flux_t *h,
                            const char *targets,
                            flux_error_t *errp);
@@ -1227,7 +1239,7 @@ char *flux_hostmap_lookup (flux_t *h,
 
 
 int flux_get_instance_starttime (flux_t *h, double *starttime);
-# 1981 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 1993 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum flux_conf_flags {
     FLUX_CONF_INSTALLED=0,
     FLUX_CONF_INTREE=1,
@@ -1280,13 +1292,13 @@ int flux_conf_vunpack (const flux_conf_t *conf,
 int flux_conf_unpack (const flux_conf_t *conf,
                       flux_error_t *error,
                       const char *fmt, ...);
-# 2065 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2077 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_barrier (flux_t *h, const char *name, int nprocs);
-# 2108 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2120 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_service_register (flux_t *h, const char *name);
-# 2120 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2132 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_service_unregister (flux_t *h, const char *name);
-# 2172 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2184 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_core_version_string (void);
 
 
@@ -1295,7 +1307,7 @@ const char *flux_core_version_string (void);
 
 
 int flux_core_version (int *major, int *minor, int *patch);
-# 2210 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2222 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum {
     FLUX_PLUGIN_RTLD_LAZY = 1,
     FLUX_PLUGIN_RTLD_NOW = 2,
@@ -1373,7 +1385,7 @@ flux_plugin_f flux_plugin_match_handler (flux_plugin_t *p, const char *topic);
 int flux_plugin_register (flux_plugin_t *p,
                           const char *name,
                           const struct flux_plugin_handler t[]);
-# 2297 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2309 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_plugin_aux_set (flux_plugin_t *p,
                          const char *key,
                          void *val,
@@ -1435,14 +1447,14 @@ int flux_plugin_arg_unpack (flux_plugin_arg_t *args, int flags,
                             const char *fmt, ...);
 int flux_plugin_arg_vunpack (flux_plugin_arg_t *args, int flags,
                              const char *fmt, va_list ap);
-# 2366 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2378 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_plugin_call (flux_plugin_t *p, const char *name,
                       flux_plugin_arg_t *args);
-# 2376 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2388 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_plugin_load_dso (flux_plugin_t *p, const char *path);
-# 2409 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2421 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_sync_create (flux_t *h, double minimum);
-# 2441 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2453 "/__w/flux-python/flux-python/src/_core_clean.h"
 bool flux_disconnect_match (const flux_msg_t *msg1, const flux_msg_t *msg2);
 
 
@@ -1462,7 +1474,7 @@ bool flux_cancel_match (const flux_msg_t *msg1, const flux_msg_t *msg2);
 int flux_msglist_cancel (flux_t *h,
                          struct flux_msglist *l,
                          const flux_msg_t *msg);
-# 2510 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2522 "/__w/flux-python/flux-python/src/_core_clean.h"
 void flux_stats_count (flux_t *h, const char *name, ssize_t count);
 
 
@@ -1498,10 +1510,10 @@ void flux_stats_set_prefix (flux_t *h, const char *fmt, ...);
 
 
 bool flux_stats_enabled (flux_t *h, const char *metric);
-# 2593 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2605 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_kvsdir flux_kvsdir_t;
 typedef struct flux_kvsitr flux_kvsitr_t;
-# 2608 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2620 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_kvsdir_t *flux_kvsdir_create (flux_t *handle, const char *rootref,
                                    const char *key, const char *json_str);
 void flux_kvsdir_destroy (flux_kvsdir_t *dir);
@@ -1547,7 +1559,7 @@ const char *flux_kvsdir_rootref (const flux_kvsdir_t *dir);
 
 
 char *flux_kvsdir_key_at (const flux_kvsdir_t *dir, const char *key);
-# 2681 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2693 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_lookup (flux_t *h, const char *ns, int flags,
                                 const char *key);
 flux_future_t *flux_kvs_lookupat (flux_t *h, int flags, const char *key,
@@ -1570,14 +1582,14 @@ const char *flux_kvs_lookup_get_key (flux_future_t *f);
 
 
 int flux_kvs_lookup_cancel (flux_future_t *f);
-# 2731 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2743 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_getroot (flux_t *h, const char *ns, int flags);
-# 2740 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2752 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_kvs_getroot_get_treeobj (flux_future_t *f, const char **treeobj);
 int flux_kvs_getroot_get_blobref (flux_future_t *f, const char **blobref);
 int flux_kvs_getroot_get_sequence (flux_future_t *f, int *seq);
 int flux_kvs_getroot_get_owner (flux_future_t *f, uint32_t *owner);
-# 2772 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2784 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_kvs_txn flux_kvs_txn_t;
 
 flux_kvs_txn_t *flux_kvs_txn_create (void);
@@ -1607,7 +1619,7 @@ int flux_kvs_txn_unlink (flux_kvs_txn_t *txn, int flags,
 int flux_kvs_txn_symlink (flux_kvs_txn_t *txn, int flags,
                           const char *key, const char *ns,
                           const char *target);
-# 2850 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2862 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum kvs_commit_flags {
     FLUX_KVS_NO_MERGE = 1,
     FLUX_KVS_TXN_COMPACT = 2,
@@ -1625,21 +1637,21 @@ flux_future_t *flux_kvs_fence (flux_t *h, const char *ns, int flags,
 int flux_kvs_commit_get_treeobj (flux_future_t *f, const char **treeobj);
 int flux_kvs_commit_get_rootref (flux_future_t *f, const char **rootref);
 int flux_kvs_commit_get_sequence (flux_future_t *f, int *rootseq);
-# 2906 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2918 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_copy (flux_t *h,
                               const char *srcns,
                               const char *srckey,
                               const char *dstns,
                               const char *dstkey,
                               int commit_flags);
-# 2923 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2935 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_move (flux_t *h,
                               const char *srcns,
                               const char *srckey,
                               const char *dstns,
                               const char *dstkey,
                               int commit_flags);
-# 2946 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2958 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum kvs_op {
     FLUX_KVS_READDIR = 1,
     FLUX_KVS_READLINK = 2,
@@ -1651,7 +1663,7 @@ enum kvs_op {
     FLUX_KVS_WATCH_UNIQ = 128,
     FLUX_KVS_WATCH_APPEND = 256
 };
-# 2967 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 2979 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_namespace_create (flux_t *h, const char *ns,
                                           uint32_t owner, int flags);
 flux_future_t *flux_kvs_namespace_create_with (flux_t *h, const char *ns,
@@ -1672,7 +1684,7 @@ int flux_kvs_wait_version (flux_t *h, const char *ns, int version);
 
 
 int flux_kvs_dropcache (flux_t *h);
-# 3015 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3027 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum job_submit_flags {
     FLUX_JOB_PRE_SIGNED = 1,
     FLUX_JOB_DEBUG = 2,
@@ -1734,10 +1746,10 @@ typedef uint64_t flux_jobid_t;
 
 
 int flux_job_id_parse (const char *s, flux_jobid_t *id);
-# 3085 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3097 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_id_encode (flux_jobid_t id, const char *type,
                         char *buf, size_t bufsz);
-# 3096 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3108 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_job_statetostr (flux_job_state_t state, const char *fmt);
 
 
@@ -1851,11 +1863,16 @@ flux_future_t *flux_job_result (flux_t *h, flux_jobid_t id, int flags);
 
 int flux_job_result_get (flux_future_t *f,
                          const char **json_str);
-# 3227 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3239 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_result_get_unpack (flux_future_t *f, const char *fmt, ...);
-# 3241 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3253 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_timeleft (flux_t *h, flux_error_t *errp, double *timeleft);
-# 3266 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3269 "/__w/flux-python/flux-python/src/_core_clean.h"
+char *flux_unwrap_string (const char *in,
+                          bool verify,
+                          uint32_t *userid,
+                          flux_error_t *error);
+# 3297 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_jobspec1 flux_jobspec1_t;
 typedef flux_error_t flux_jobspec1_error_t;
 
@@ -1953,7 +1970,7 @@ char *flux_jobspec1_encode (flux_jobspec1_t *jobspec, size_t flags);
 
 flux_jobspec1_t *flux_jobspec1_decode (const char *s,
                                        flux_jobspec1_error_t *error);
-# 3377 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3408 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_jobspec1_t *flux_jobspec1_from_command (int argc,
                                              char **argv,
                                              char **env,
@@ -1965,7 +1982,7 @@ flux_jobspec1_t *flux_jobspec1_from_command (int argc,
 
 
 void flux_jobspec1_destroy (flux_jobspec1_t *jobspec);
-# 3419 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3450 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_command flux_cmd_t;
 
 
@@ -1975,7 +1992,7 @@ typedef struct flux_command flux_cmd_t;
 
 
 typedef struct flux_subprocess flux_subprocess_t;
-# 3439 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3470 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef enum {
     FLUX_SUBPROCESS_INIT,
     FLUX_SUBPROCESS_RUNNING,
@@ -2048,9 +2065,9 @@ typedef void (*subprocess_log_f) (void *arg,
                                   int level,
                                   const char *fmt,
                                   va_list args);
-# 3523 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3554 "/__w/flux-python/flux-python/src/_core_clean.h"
 void flux_standard_output (flux_subprocess_t *p, const char *stream);
-# 3532 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3563 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_cmd_t * flux_cmd_create (int argc, char *argv[], char **env);
 
 
@@ -2110,6 +2127,7 @@ int flux_cmd_setenvf (flux_cmd_t *cmd, int overwrite,
 
 
 
+
 void flux_cmd_unsetenv (flux_cmd_t *cmd, const char *name);
 
 
@@ -2124,12 +2142,12 @@ const char *flux_cmd_getenv (const flux_cmd_t *cmd, const char *name);
 
 int flux_cmd_setcwd (flux_cmd_t *cmd, const char *cwd);
 const char *flux_cmd_getcwd (const flux_cmd_t *cmd);
-# 3618 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3650 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_cmd_add_channel (flux_cmd_t *cmd, const char *name);
-# 3668 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3700 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_cmd_setopt (flux_cmd_t *cmd, const char *var, const char *val);
 const char *flux_cmd_getopt (flux_cmd_t *cmd, const char *var);
-# 3691 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3723 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_subprocess_t *flux_local_exec (flux_reactor_t *r,
                                     int flags,
                                     const flux_cmd_t *cmd,
@@ -2155,7 +2173,7 @@ flux_subprocess_t *flux_rexec_ex (flux_t *h,
                                   const flux_subprocess_ops_t *ops,
                                   subprocess_log_f log_fn,
                                   void *log_data);
-# 3726 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3758 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_subprocess_stream_start (flux_subprocess_t *p, const char *stream);
 int flux_subprocess_stream_stop (flux_subprocess_t *p, const char *stream);
 int flux_subprocess_stream_status (flux_subprocess_t *p, const char *stream);
@@ -2175,11 +2193,11 @@ int flux_subprocess_write (flux_subprocess_t *p, const char *stream,
 
 
 int flux_subprocess_close (flux_subprocess_t *p, const char *stream);
-# 3757 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3789 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_subprocess_read (flux_subprocess_t *p,
                                   const char *stream,
                                   int len, int *lenp);
-# 3772 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3804 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_subprocess_read_line (flux_subprocess_t *p,
                                        const char *stream,
                                        int *lenp);
@@ -2190,10 +2208,10 @@ const char *flux_subprocess_read_line (flux_subprocess_t *p,
 const char *flux_subprocess_read_trimmed_line (flux_subprocess_t *p,
                                                const char *stream,
                                                int *lenp);
-# 3792 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3824 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_subprocess_read_stream_closed (flux_subprocess_t *p,
                                         const char *stream);
-# 3811 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3843 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_subprocess_getline (flux_subprocess_t *p,
                                      const char *stream,
                                      int *lenp);
@@ -2213,7 +2231,7 @@ flux_future_t *flux_subprocess_kill (flux_subprocess_t *p, int signo);
 
 void flux_subprocess_ref (flux_subprocess_t *p);
 void flux_subprocess_unref (flux_subprocess_t *p);
-# 3838 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+# 3870 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_subprocess_state_t flux_subprocess_state (flux_subprocess_t *p);
 
 
@@ -2228,6 +2246,12 @@ int flux_subprocess_fail_errno (flux_subprocess_t *p);
 
 
 
+
+
+const char *flux_subprocess_fail_error (flux_subprocess_t *p);
+
+
+
 int flux_subprocess_status (flux_subprocess_t *p);
 
 
@@ -2261,7 +2285,15 @@ int flux_subprocess_aux_set (flux_subprocess_t *p,
 
 
 void *flux_subprocess_aux_get (flux_subprocess_t *p, const char *name);
-# 3899 "/home/runner/work/flux-python/flux-python/src/_core_clean.h"
+
+
+
+
+
+
+void flux_subprocess_channel_incref (flux_subprocess_t *p, const char *name);
+void flux_subprocess_channel_decref (flux_subprocess_t *p, const char *name);
+# 3944 "/__w/flux-python/flux-python/src/_core_clean.h"
 extern "Python" void message_handler_wrapper(flux_t *, flux_msg_handler_t *, const flux_msg_t *, void *);
 
 
